# Buildutils

Utilities for build system

[![Build Status](https://travis-ci.org/TediCreations/buildutil.svg?branch=master)](https://travis-ci.org/TediCreations/buildutil)

### Installation

```sh
$ pip install buildutil
```

# License

MIT
